View source: R/plot.study.dissimilarities_function.R
| plot_study_dissimilarities | R Documentation |
Illustrating the range of Gower's dissimilarity values for each study in the network, as well as their between- and within-comparison dissimilarities
plot_study_dissimilarities(
results,
axis_title_size = 12,
axis_text_size = 12,
strip_text_size = 11,
label_size = 3.5
)
results |
An object of S3 class |
axis_title_size |
A positive integer for the font size of axis title
(both axes). |
axis_text_size |
A positive integer for the font size of axis text (both
axes). |
strip_text_size |
A positive integer for the font size of facet labels.
|
label_size |
A positive integer for the font size of labels appearing on
each study-specific segment. |
The range of Gower's dissimilarity values for each study versus the remaining studies in the network for a set of clinical and methodological characteristics that may act as effect modifiers. Gower's dissimilarities take values from 0 to 1, with 0 and 1 implying perfect similarity and perfect dissimilarity, respectively.
The unique dissimilarity values appear as dotted, vertical, grey lines on each study
A horizontal bar plot illustrating the range of Gower's dissimilarity
values for each study with those found in other comparisons. The
study names appear on the y-axis in the order they appear in results
and the dissimilarity values appear on the x-axis. Red and blue points refer
to the (average) within-comparison and between-comparison dissimilarity,
respectively, for each study.
A data-frame on the (average) within-comparison and between-comparison
dissimilarities for each study alongside the study name and comparison.
The last two columns refer to the within-comparison and between-comparison
dissimilarities, respectively, after replacing with the maximum value in the
multi-arm trials. These two columns should be used as a covariate in the
function study_perc_contrib to obtain the
percentage contribution of each study based on the covariate values.
Loukia M. Spineli
Gower J. General Coefficient of Similarity and Some of Its Properties. Biometrics 1971;27(4):857–71. doi: 10.2307/2528823
comp_clustering, study_perc_contrib
# Fictional dataset
data_set <- data.frame(Trial_name = paste("study", as.character(1:7)),
arm1 = c("1", "1", "1", "1", "1", "2", "2"),
arm2 = c("2", "2", "2", "3", "3", "3", "3"),
sample = c(140, 145, 150, 40, 45, 75, 80),
age = c(18, 18, 18, 48, 48, 35, 35),
blinding = as.integer(c("yes", "yes", "yes", "no", "no", "no", "no")))
# Obtain comparison dissimilarities (informative = TRUE)
res <- comp_clustering(input = data_set,
drug_names = c("A", "B", "C"),
threshold = 0.13, # General research setting
informative = TRUE,
get_plots = TRUE)
plot_study_dissimilarities(results = res,
axis_title_size = 12,
axis_text_size = 12,
strip_text_size = 11,
label_size = 3.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.