View source: R/scatterplot.sucra_function.R
| scatterplot_sucra | R Documentation |
Creates a scatterplot of the SUCRA values from the network meta-analysis and the network meta-regression for a specified level or value of the investigated covariate.
scatterplot_sucra(full, reg, cov_name = "covariate value", drug_names)
full |
An object of S3 class |
reg |
An object of S3 class |
cov_name |
A character or text to indicate the name of the covariate. |
drug_names |
A vector of labels with the name of the interventions in
the order they appear in the argument |
The names of the interventions appear above each point in the plot. Three coloured rectangles are drawn in the scatterplot: a red rectangle for SUCRA values up to 50%, a yellow rectangular for SUCRA values between 50% and 80%, and a green rectangle for SUCRA values over 80%. Interventions falling at the green area are considered as the highest ranked interventions, whilst interventions falling at the red area are considered as the lowest ranked interventions.
scatterplot_sucra is integrated in metareg_plot.
scatterplot_sucra can be used only for a network of interventions.
Otherwise, the execution of the function will be stopped and an error
message will be printed on the R console.
A scatterplot of the SUCRA values under the network meta-analysis (y-axis) against the SUCRA values under the network meta-regression (x-axis) for a specified level or value of the investigated covariate.
Loukia M. Spineli
Salanti G, Ades AE, Ioannidis JP. Graphical methods and numerical summaries for presenting results from multiple-treatment meta-analysis: an overview and tutorial. J Clin Epidemiol 2011;64(2):163–71. doi: 10.1016/j.jclinepi.2010.03.016
metareg_plot, run_metareg,
run_model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.